@@ -1,21 +1,10 @@
 """
-  Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-
-  Permission is hereby granted, free of charge, to any person obtaining a copy of this
-  software and associated documentation files (the "Software"), to deal in the Software
-  without restriction, including without limitation the rights to use, copy, modify,
-  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
-  permit persons to whom the Software is furnished to do so.
-
-  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
-  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
-  PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
-  OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+SPDX-License-Identifier: MIT-0
 """
 import json
-from cfnlint import Match
+from cfnlint.rules import Match
+
 
 class BaseFormatter(object):
     """Base Formatter class"""
@@ -35,8 +24,10 @@ class BaseFormatter(object):
 
         return '\n'.join(output)
 
+
 class Formatter(BaseFormatter):
     """Generic Formatter"""
+
     def _format(self, match):
         """Format output"""
         formatstr = u'{0} {1}\n{2}:{3}:{4}\n'
@@ -48,12 +39,14 @@ class Formatter(BaseFormatter):
             match.columnnumber
         )
 
+
 class JsonFormatter(BaseFormatter):
     """Json Formatter"""
 
     class CustomEncoder(json.JSONEncoder):
         """Custom Encoding for the Match Object"""
         # pylint: disable=E0202
+
         def default(self, o):
             if isinstance(o, Match):
                 if o.rule.id[0] == 'W':
@@ -96,6 +89,7 @@ class JsonFormatter(BaseFormatter):
 
 class QuietFormatter(BaseFormatter):
     """Quiet Formatter"""
+
     def _format(self, match):
         """Format output"""
         formatstr = u'{0} {1}:{2}'
@@ -108,6 +102,7 @@ class QuietFormatter(BaseFormatter):
 
 class ParseableFormatter(BaseFormatter):
     """Parseable Formatter"""
+
     def _format(self, match):
         """Format output"""
         formatstr = u'{0}:{1}:{2}:{3}:{4}:{5}:{6}'
